@@ -50,7 +50,7 @@
 
 typedef struct {
         GtkLabel *progress_label;
-        GtkProgress *progress_bar;
+        GtkProgressBar *progress_bar;
 } ProgressChangeData;
 
 typedef struct {
@@ -103,7 +103,8 @@ update_progress_display (gpointer callback_data)
         progress_string = get_text_for_progress_label ();
         gtk_label_set_text (progress_label, progress_string);
         g_free (progress_string);
-        gtk_progress_set_value (progress_change_data->progress_bar, get_index_percentage_complete ());
+        gtk_progress_bar_set_fraction (progress_change_data->progress_bar, 
+                                       get_index_percentage_complete () / 100.0f);
 
 
         return TRUE;
@@ -130,10 +131,9 @@ show_index_progress_dialog (void)
         gtk_widget_show_all (GTK_WIDGET (dialogs->index_in_progress_dialog));
         callback_id = medusa_execute_once_when_system_state_changes (dialog_close_cover,
                                                                      dialogs->index_in_progress_dialog);
-        g_signal_connect_object (G_OBJECT (dialogs->index_in_progress_dialog),
-				 "destroy",
-				 G_CALLBACK (medusa_remove_state_changed_function),
-				 GINT_TO_POINTER (callback_id), 0);
+        g_signal_connect_swapped (dialogs->index_in_progress_dialog, "destroy",
+                                  G_CALLBACK (medusa_remove_state_changed_function),
+                                  GINT_TO_POINTER (callback_id));
 }
 
 
@@ -148,10 +148,9 @@ show_last_index_time_dialog (void)
         gtk_widget_show_all (GTK_WIDGET (dialogs->last_index_time_dialog));
         callback_id = medusa_execute_once_when_system_state_changes (dialog_close_cover,
                                                                      dialogs->last_index_time_dialog);
-        g_signal_connect_object (G_OBJECT (dialogs->last_index_time_dialog),
-				 "destroy",
-				 G_CALLBACK (medusa_remove_state_changed_function),
-				 GINT_TO_POINTER (callback_id), 0);
+        g_signal_connect_swapped (dialogs->last_index_time_dialog, "destroy",
+                                  G_CALLBACK (medusa_remove_state_changed_function),
+                                  GINT_TO_POINTER (callback_id));
 }
 
 static GtkDialog *
@@ -162,23 +161,18 @@ last_index_time_dialog_new (void)
         GtkWidget *label;
         GtkDialog *dialog;
 
-        dialog = eel_create_info_dialog (_("Once a day your files and text content are indexed so "
+        time_str = nautilus_indexing_info_get_last_index_time ();
+        label_str = g_strdup_printf (_("Your files were last indexed at %s."),
+                                     time_str);
+        g_free (time_str);
+	
+        dialog = eel_create_info_dialog (label_str,
+	                                 _("Once a day your files and text content are indexed so "
                                            "your searches are fast. "),
                                          _("Indexing Status"),
                                          NULL);
         set_close_hides_for_dialog (dialog);
 
-        time_str = nautilus_indexing_info_get_last_index_time ();
-        label_str = g_strdup_printf (_("Your files were last indexed at %s"),
-                                     time_str);
-        g_free (time_str);
-        
-        label = gtk_label_new (label_str);
-        gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
-        eel_gtk_label_make_bold (GTK_LABEL (label));
-        gtk_box_pack_start (GTK_BOX (dialog->vbox), label,
-                            FALSE, FALSE, 0);
-
         return dialog;
 }
 
@@ -200,8 +194,9 @@ index_progress_dialog_new (void)
         ProgressChangeData *progress_data;
         guint timeout_id;
                 
-        dialog = eel_create_info_dialog (_("Once a day your files and text content are indexed so "
-                                           "your searches are fast.  Your files are currently being indexed."),
+        dialog = eel_create_info_dialog (_("Your files are currently being indexed."),
+                                         _("Once a day your files and text content are indexed so "
+                                           "your searches are fast."), 
                                          _("Indexing Status"), NULL);
         set_close_hides_for_dialog (dialog);        
         percentage_complete = get_index_percentage_complete ();
@@ -209,8 +204,8 @@ index_progress_dialog_new (void)
 
         embedded_vbox = gtk_vbox_new (FALSE, GNOME_PAD_SMALL);
 
-        gtk_progress_set_show_text (GTK_PROGRESS (indexing_progress_bar), FALSE);
-        gtk_progress_configure (GTK_PROGRESS (indexing_progress_bar), percentage_complete, 0, 100);
+        /* turn off text display by setting text to NULL */
+        gtk_progress_bar_set_text (GTK_PROGRESS_BAR (indexing_progress_bar), NULL);
         /* Put the progress bar in an hbox to make it a more sane size */
         gtk_box_pack_start (GTK_BOX (embedded_vbox), indexing_progress_bar, FALSE, FALSE, 0);
 
@@ -229,16 +224,15 @@ index_progress_dialog_new (void)
         /* Keep the dialog current with actual indexing progress */
         progress_data = g_new (ProgressChangeData, 1);
         progress_data->progress_label = GTK_LABEL (progress_label);
-        progress_data->progress_bar = GTK_PROGRESS (indexing_progress_bar);
+        progress_data->progress_bar = GTK_PROGRESS_BAR (indexing_progress_bar);
         timeout_id = gtk_timeout_add_full (PROGRESS_UPDATE_INTERVAL,
                                            update_progress_display,
                                            NULL,
                                            progress_data,
                                            g_free);
-        g_signal_connect (progress_bar_hbox,
-                            "destroy",
-			    G_CALLBACK (timeout_remove_callback),
-                            GUINT_TO_POINTER (timeout_id));
+        g_signal_connect (progress_bar_hbox, "destroy", /* FIXME: will be called twice */
+                          G_CALLBACK (timeout_remove_callback),
+                          GLONG_TO_POINTER (timeout_id));
         
         return dialog;
 }
@@ -260,11 +254,12 @@ show_indexing_info_dialog (void)
 
         if (!medusa_system_services_are_enabled ()) {
                 details_string = nautilus_medusa_get_explanation_of_enabling ();
-                dialog_shown = eel_show_info_dialog_with_details (_("When Fast Search is enabled, Find creates an "
+                dialog_shown = eel_show_info_dialog_with_details (_("There is no index of your files right now."),
+                                                                    _("When Fast Search is enabled, Find creates an "
                                                                     "index to speed up searches.  Fast searching "
                                                                     "is not enabled on your computer, so you "
                                                                     "do not have an index right now."),
-                                                                  _("There is no index of your files right now."),
+								    _("No Index of Files"),
                                                                     details_string,
                                                                   NULL);
                 g_free (details_string);
@@ -272,10 +267,9 @@ show_indexing_info_dialog (void)
                 
                 callback_id = medusa_execute_once_when_system_state_changes (dialog_close_cover,
                                                                              dialog_shown);
-                g_signal_connect_object (G_OBJECT (dialog_shown),
-					 "destroy",
-					 G_CALLBACK (medusa_remove_state_changed_function),
-					 GINT_TO_POINTER (callback_id), 0);
+                g_signal_connect_swapped (dialog_shown, "destroy",
+                                          G_CALLBACK (medusa_remove_state_changed_function),
+                                          GINT_TO_POINTER (callback_id));
                 return;
         }
 	if (dialogs == NULL) {
@@ -303,6 +297,7 @@ static void
 show_search_service_not_available_dialog (void)
 {
         eel_show_error_dialog (_("Sorry, but the medusa search service is not available."),
+                                    _("Please verify medusa has been setup correctly."),
                                     _("Search Service Not Available"),
                                     NULL);
 }
